==> haskell-mockery-0.3.5-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-D3BqPaKiYwe2lYhMOJgfoB
key: mockery-0.3.5-D3BqPaKiYwe2lYhMOJgfoB
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: 98131078b8b77924d74b6f9ef4089e49
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.6.1/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.6.1/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-D3BqPaKiYwe2lYhMOJgfoB
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 directory-1.3.3.0 filepath-1.4.2.1
    logging-facade-0.3.0-JWaPZeF9Dpt6UDtXU4fDiX
    temporary-1.3-3WeKdZxRfOx2W7bb9ggxeO
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-A5d0EsTph5fJMusyHudpL5
key: mockery-0.3.5-A5d0EsTph5fJMusyHudpL5
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: eea0767d34022fdf3dcc0e5c91dab2c3
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.6.2/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.6.2/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-A5d0EsTph5fJMusyHudpL5
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 directory-1.3.3.0 filepath-1.4.2.1
    logging-facade-0.3.0-KHQeML57OlL4frWB9RXbyL
    temporary-1.3-u08bcW55BD8R66ioRtSEF
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
